// CPUView.h
// Copyright(C) 1999 by Kiyoshi Kobayashi. All rights reserved.
//
//

#ifndef _CPU_VIEW_H_
#define _CPU_VIEW_H_

#include <View.h>
#include <Rect.h>
#include <List.h>
#include <StringView.h>

#include "BaseView.h"
#include "LabelStringView.h"
#include "LineGraphView.h"
#include "SysInfo.h"
#include "SysInfoObserver.h"

// class CPUView
// This class is responsible for draw a CPU active rate
// in line graph and string.
class _EXPORT CPUView : public BaseView {
  public:
	CPUView(BRect frame, int32 cpuId);
	CPUView(BMessage *archive);
	virtual ~CPUView();
	
	inline int32 GetId() const { return id; };
	void Update(float rate);
	
	// Override BView methods
	void AttachedToWindow();
	void FrameResized(float width, float height);
	
	// Archivable
	status_t Archive(BMessage *archive, bool deep) const;
	static BArchivable *Instantiate(BMessage *archive);

  private:
	// To avoid misuse
	CPUView(const CPUView &);
	CPUView &operator=(const CPUView &) { return *this; };
	
	// Adjust itself
	void Adjust(float width, float height);
	
	// Holds history of CPU active rate
	BList list;
	
	LabelStringView *sView;
	LineGraphView *gView;
	SysInfoObserver *obs;
	
	char name[256];
	int32 id;
};

#endif /* _CPU_VIEW_H_ */
