#undef DEBUG
//LabelStringView.cpp
// Copyright(C) 1999 by Kiyoshi Kobayashi. All rights reserved.
//
//
#include <Point.h>
#include <OS.h>
#include <Debug.h>
#include <stdio.h>
#include <string.h>
#include "LabelStringView.h"

static const char CLASS_NAME[] = "LabelStringView";
static const char VIEW_NAME[] = "LabelStringView";

static const float MARGIN = 0.0f;
static const float STR_VIEW_HEIGHT = 10.0f;
static const float FONT_SIZE = 9.0f;

// Public: Constructor.
//
LabelStringView::LabelStringView(BRect frame, const char *label,
					const char *value, const char *unit)
	: BView(frame, VIEW_NAME, B_FOLLOW_ALL, B_WILL_DRAW|B_FRAME_EVENTS) {
	_labelView = new BStringView(frame, "Label", label,
								 B_FOLLOW_ALL, B_WILL_DRAW);
	AddChild(_labelView);
	_valueView = new BStringView(frame, "Value", value,
								 B_FOLLOW_ALL, B_WILL_DRAW);
	AddChild(_valueView);
	_unitView = new BStringView(frame, "Unit", unit,
								 B_FOLLOW_ALL, B_WILL_DRAW);
	AddChild(_unitView);
}

// Public: Constructor from the archive.
//
LabelStringView::LabelStringView(BMessage *archive)
	: BView(archive) {
	// restore transient pointer to the children
	//
	BView *child = this->ChildAt(0);

	while (child != NULL) {
		if (is_instance_of(child, BStringView)) {
			BStringView *s = cast_as(child, BStringView);
			printf("---------------------%s\n", s->Name());
			if (strncmp(s->Name(), "Label", 4) == 0)
				_labelView = s;
			else if (strncmp(s->Name(), "Value", 4) == 0)
				_valueView = s;
			else if (strncmp(s->Name(), "Unit", 4) == 0)
				_unitView = s;
		}
		
		child = child->NextSibling();
	}
	
	ASSERT(_labelView != NULL);
	ASSERT(_valueView != NULL);
	ASSERT(_unitView != NULL);
}

// Public: Destructor.
//
LabelStringView::~LabelStringView() {}

// Public: Update the contents.
//
void
LabelStringView::Update(const char *value) {
	_valueView->SetText(value);
}

// Public: Override BView method.
//
void
LabelStringView::AttachedToWindow() {
	if (Parent()) {
		const rgb_color view = Parent()->ViewColor();
		SetViewColor(view);
		_labelView->SetViewColor(view);
		_labelView->SetFontSize(FONT_SIZE);
		_labelView->SetAlignment(B_ALIGN_LEFT);
		
		_valueView->SetViewColor(view);
		_valueView->SetFontSize(FONT_SIZE);
		_valueView->SetAlignment(B_ALIGN_RIGHT);
		
		_unitView->SetViewColor(view);
		_unitView->SetFontSize(FONT_SIZE);
		_unitView->SetAlignment(B_ALIGN_LEFT);

		//Adjust(Frame().Width(), Frame().Height());
		Adjust();
	}
	
	BView::AttachedToWindow();
}

// Public: Override BView method.
//
void
LabelStringView::FrameResized(float width, float height) {
	//Adjust(width, height);
	Adjust();

	BView::FrameResized(width, height);
}

// Public: Archive the object.
//
status_t
LabelStringView::Archive(BMessage *archive, bool deep) const {
	status_t ret;
	ret = BView::Archive(archive, deep);
	ASSERT(ret == B_OK);

	ret = archive->AddString("class", CLASS_NAME);
	ASSERT(ret == B_OK);
	
	return B_OK;
}

// Public/Static: Instanciate the object.
//
BArchivable *
LabelStringView::Instantiate(BMessage *archive) {
	if (validate_instantiation(archive, CLASS_NAME))
		return new LabelStringView(archive); 
		
	return NULL; 
}

// Private:
//
LabelStringView::LabelStringView(const LabelStringView &)
	: BView(BRect(), VIEW_NAME, B_FOLLOW_ALL, B_WILL_DRAW) {}

// Private: Adjust the size.
//
void
LabelStringView::Adjust() {
	_labelView->MoveTo(MARGIN, MARGIN);
	_labelView->ResizeTo(30.0f, 10.0f);
	_labelView->Invalidate();

	_valueView->MoveTo(_labelView->Frame().RightTop());
	_valueView->ResizeTo(15.0f, 10.0f);
	_valueView->Invalidate();

	_unitView->MoveTo(_valueView->Frame().RightTop());
	_unitView->ResizeTo(10.0f, 10.0f);
	_unitView->Invalidate();

//	PRINT_OBJECT(_labelView->Frame());
//	PRINT_OBJECT(_valueView->Frame());
//	PRINT_OBJECT(_unitView->Frame());
}

