// MeterBaseView.h
// Copyright(C) 1999 by Kiyoshi Kobayashi. All rights reserved.
//
//
#ifndef _METER_BASE_VIEW_H_
#define _METER_BASE_VIEW_H_

#include <View.h>
#include <Rect.h>
#include <Message.h>
#include <Looper.h>
#include <MessageRunner.h>
#include <PopUpMenu.h>

#include "SysInfo.h"
#include "SysInfoDeltaGenerator.h"
#include "LayoutManager.h"
#include "BaseView.h"
#include "MeterMessages.h"

// The instance of this class is supposed to become a parent of all other
// view instances in this app.
// It's also a replicant view!
//
class _EXPORT MeterBaseView : public BaseView {
public:
	MeterBaseView(BRect frame, LayoutType type = LT_VERTICAL,
				  bool all = false, bigtime_t intvl = 2000000);
	MeterBaseView(BMessage *archive);
	virtual ~MeterBaseView();
	
	// Override BView methods
	virtual void AllAttached();
	virtual void FrameResized(float width, float height);
	virtual void MessageReceived(BMessage *msg);
	
	// Archivable
	virtual status_t Archive(BMessage *archive, bool deep) const;
	static BArchivable *Instantiate(BMessage *archive);
	
	// PopUpMenuInterest
	virtual void AddMenuItems(BPopUpMenu *menu);
	
	inline LayoutType GetLayoutType() { return lm->GetLayoutType(); };
	inline bool GetAllWorkspaces() { return allWorkspaces; };
	inline bigtime_t GetInterval() { return interval; };
	
private:
	MeterBaseView(const MeterBaseView &);
	MeterBaseView &operator=(const MeterBaseView &) { return *this; };
	
	bigtime_t interval;	// The interval of "PING".
	bool allWorkspaces;
	
	BMessageRunner *mr;	// The "PING" event generator.
	SysInfoDeltaGenerator *gen;	// The generator of delta of SysInfo.
	LayoutManager *lm;	// The layout manager.
};

#endif /* _METER_BASE_VIEW_H_ */
